@@ -58,14 +58,21 @@ static void LIBPQ_update_transaction_status(ConnectionClass *self);
 
 static void CC_set_error_if_not_set(ConnectionClass *self, int errornumber, const char *errormsg, const char *func)
 {
-	if (CC_get_errornumber(self) <= 0)
+	int	errornum = CC_get_errornumber(self);
+	const char *errmsg = CC_get_errormsg(self);
+
+	if (errornumber == 0)
+		return;
+	if (errornumber > 0)
 	{
-		if (CC_get_errormsg(self) == NULL)
+		if (errornum <= 0)
 			CC_set_error(self, errornumber, errormsg, func);
-		else
-			CC_set_errornumber(self, errornumber);
+		else if (!errmsg)
+			CC_set_errormsg(self, errormsg);
 	}
-	else
+	else if (errornum == 0)
+		CC_set_error(self, errornumber, errormsg, func);
+	else if (errornum < 0 && !errmsg)
 		CC_set_errormsg(self, errormsg);
 }
 
@@ -587,6 +594,7 @@ CC_determine_locale_encoding(ConnectionClass *self)
 	const char *dbencoding = PQparameterStatus(self->pqconn, "client_encoding");
 	const char *encoding;
 
+	QLOG(0, "PQparameterStatus(%p, \"client_encoding\")=%s\n", self->pqconn, SAFE_STR(dbencoding));
 	if (self->locale_encoding) /* already set */
                 return;
 	encoding = derive_locale_encoding(dbencoding);
@@ -979,7 +987,6 @@ static char CC_initial_log(ConnectionClass *self, const char *func)
 #endif /* _MSC_VER */
 		);
 	QLOG(0, "%s", vermsg);
-	MYLOG(0, "%s", vermsg);
 	MYLOG(1, "Global Options: fetch=%d, unknown_sizes=%d, max_varchar_size=%d, max_longvarchar_size=%d\n",
 		 ci->drivers.fetch_max,
 		 ci->drivers.unknown_sizes,
@@ -1246,8 +1253,14 @@ CC_remove_statement(ConnectionClass *self, StatementClass *stmt)
 char CC_get_escape(const ConnectionClass *self)
 {
 	const char	   *scf;
+	static const ConnectionClass *conn = NULL;
 
 	scf = PQparameterStatus(self->pqconn, "standard_conforming_strings");
+	if (self != conn)
+	{
+		QLOG(0, "PQparameterStatus(%p, \"standard_conforming_strings\")=%s\n", self->pqconn, SAFE_STR(scf));
+		conn = self;
+	}
 	if (scf == NULL)
 	{
 		/* we're connected to a pre-8.1 server, and E'' is not supported */
@@ -1583,15 +1596,20 @@ MYLOG(0, "entering\n");
 static BOOL
 is_setting_search_path(const char *query)
 {
-	for (query += 4; *query; query++)
+	const char *q = query;
+	if (strnicmp(q, "set", 3) != 0)
+		return FALSE;
+	q += 3;
+	while (isspace(*q)) q++;
+	for (; *q; q++)
 	{
-		if (!isspace((unsigned char) *query))
+		if (IS_NOT_SPACE(*q))
 		{
-			if (strnicmp(query, "search_path", 11) == 0)
+			if (strnicmp(q, "search_path", 11) == 0)
 				return TRUE;
-			query++;
-			while (*query && !isspace((unsigned char) *query))
-				query++;
+			q++;
+			while (IS_NOT_SPACE(*q))
+				q++;
 		}
 	}
 	return FALSE;
@@ -1639,7 +1657,6 @@ CC_internal_rollback(ConnectionClass *self, int rollback_type, BOOL ignore_abort
 	{
 		case PER_STATEMENT_ROLLBACK:
 			GenerateSvpCommand(self, INTERNAL_ROLLBACK_OPERATION, cmd, sizeof(cmd));
-			MYLOG(0, " rollback_type=%d %s\n", rollback_type, cmd);
 			QLOG(0, "PQexec: %p '%s'\n", self->pqconn, cmd);
 			pgres = PQexec(self->pqconn, cmd);
 			switch (PQresultStatus(pgres))
@@ -1660,7 +1677,6 @@ CC_internal_rollback(ConnectionClass *self, int rollback_type, BOOL ignore_abort
 		case PER_QUERY_ROLLBACK:
 			SPRINTF_FIXED(cmd, "%s TO %s;%s %s"
 				, rbkcmd, per_query_svp , rlscmd, per_query_svp);
-			MYLOG(0, " query_rollback PQsendQuery %s\n", cmd);
 			QLOG(0, "PQsendQuery: %p '%s'\n", self->pqconn, cmd);
 			PQsendQuery(self->pqconn, cmd);
 			ret = 0;
@@ -1863,7 +1879,6 @@ CC_send_query_append(ConnectionClass *self, const char *query, QueryInfo *qi, UD
 		CC_set_error(self, CONN_NO_MEMORY_ERROR, "Couldn't alloc buffer for query.", "");
 		goto cleanup;
 	}
-MYLOG(1, "query_buf=%s(" FORMAT_SIZE_T ")\n", query_buf.data, strlen(query_buf.data));
 
 	/* Set up notice receiver */
 	nrarg.conn = self;
@@ -1911,7 +1926,6 @@ MYLOG(1, "query_buf=%s(" FORMAT_SIZE_T ")\n", query_buf.data, strlen(query_buf.d
 				/* portal query command, no tuples returned */
 				/* read in the return message from the backend */
 				cmdbuffer = PQcmdStatus(pgres);
-				MYLOG(0, " ok - 'C' - %s\n", cmdbuffer);
 				QLOG(0, "\tok: - 'C' - %s\n", cmdbuffer);
 
 				if (query_completed)	/* allow for "show" style notices */
@@ -2159,7 +2173,10 @@ MYLOG(1, " rollback_on_error=%d CC_is_in_trans=%d discard_next_savepoint=%d quer
 				ignore_abort_on_conn = FALSE;
 		}
 		else if (CC_is_in_error_trans(self))
+		{
+			QLOG(0, "PQexec: %p '%s'\n", self->pqconn, rbkcmd);
 			pgres = PQexec(self->pqconn, rbkcmd);
+		}
 		/*
 		 * XXX: we don't check the result here. Should we? We're rolling back,
 		 * so it's not clear what else we can do on error. Giving an error
@@ -2370,7 +2387,6 @@ CC_send_function(ConnectionClass *self, const char *fn_name, void *result_buf, i
 	*actual_result_len = PQgetlength(pgres, 0, 0);
 
 	QLOG(0, "\tgot result with length: %d\n", *actual_result_len);
-	MYLOG(0, "got result with length %d\n", *actual_result_len);
 
 	if (*actual_result_len > 0)
 	{
@@ -2775,7 +2791,7 @@ LIBPQ_connect(ConnectionClass *self)
 	opts[cnt] = vals[cnt] = NULL;
 	/* Ok, we're all set to connect */
 
-	if (get_qlog() > 0)
+	if (get_qlog() > 0 || get_mylog() > 0)
 	{
 		const char **popt, **pval;
 
@@ -2919,16 +2935,16 @@ make_lstring_ifneeded(ConnectionClass *conn, const SQLCHAR *s, ssize_t len, BOOL
 	if (s && (len > 0 || (len == SQL_NTS && (length = strlen(ccs)) > 0)))
 	{
 		int	i;
-		const UCHAR *ptr;
+		UCHAR tchar;
 		encoded_str encstr;
 
 		make_encoded_str(&encstr, conn, ccs);
-		for (i = 0, ptr = (const UCHAR *) ccs; i < length; i++, ptr++)
+		for (i = 0; i < length; i++)
 		{
-			encoded_nextchar(&encstr);
-			if (ENCODE_STATUS(encstr) != 0)
+			tchar = encoded_nextchar(&encstr);
+			if (MBCS_NON_ASCII(encstr))
 				continue;
-			if (ifallupper && islower(*ptr))
+			if (ifallupper && islower(tchar))
 			{
 				if (str)
 				{
@@ -2937,7 +2953,7 @@ make_lstring_ifneeded(ConnectionClass *conn, const SQLCHAR *s, ssize_t len, BOOL
 				}
 				break;
 			}
-			if (tolower(*ptr) != *ptr)
+			if (tolower(tchar) != tchar)
 			{
 				if (!str)
 				{
@@ -2946,7 +2962,7 @@ make_lstring_ifneeded(ConnectionClass *conn, const SQLCHAR *s, ssize_t len, BOOL
 					memcpy(str, s, length);
 					str[length] = '\0';
 				}
-				str[i] = tolower(*ptr);
+				str[i] = tolower(tchar);
 			}
 		}
 	}
