@@ -39,11 +39,14 @@ private:
 	vector<string>	qvec;
 	int		pos;
 	bool	immediateConnection;
+	string	sqlState;
+	string	errMsg;
 
 	void	parse_xa_info();
 public:
 	XAConnection(LPCTSTR str) : connstr(str), xaconn(NULL), pos(-1), immediateConnection(false) {parse_xa_info();}
 	~XAConnection();
+	void	Reset(void);
 	HDBC	ActivateConnection(void);
 	void	SetPos(int spos) {pos = spos;}
 	HDBC	GetConnection(void) const {return xaconn;}
@@ -52,6 +55,7 @@ public:
 	const string &GetConnstr(void) {return connstr;}
 	const string &GetDsnstr(void) {return dsnstr;}
 	bool	GetImmediateConnection(void) {return immediateConnection;}
+	bool	AuthenticationError(void) {return sqlState == "08001" && errMsg.find("could not connect") == std::string::npos;}
 };
 
 static class INIT_CRIT
@@ -74,20 +78,13 @@ public:
 	~INIT_CRIT()
 	{
 // mylog("Leaving INIT_CRIT\n");
-		if (cs_init)
-		{
-			xatab.clear();
-			FreeEnv();
-			if (LOGFP)
-				fclose(LOGFP);
-			DeleteCriticalSection(&mylog_cs);
-			DeleteCriticalSection(&map_cs);
-		}
+		leave();
 	}
-	void finalize()
+	void leave()
 	{
 		if (cs_init)
 		{
+			mylog("leaving pgxadll\n");
 			xatab.clear();
 			FreeEnv();
 			if (LOGFP)
@@ -98,10 +95,15 @@ public:
 			cs_init = false;
 		}
 	}
+	void finalize()
+	{
+		leave();
+	}
 	void FreeEnv()
 	{
 		if (env)
 		{
+			mylog("Freeing env\n");
 			SQLFreeHandle(SQL_HANDLE_ENV, env);
 			env = NULL;
 		}
@@ -113,10 +115,19 @@ public:
 static int dtclog = 0;
 
 XAConnection::~XAConnection()
+{
+}
+
+void XAConnection::Reset()
 {
 	qvec.clear();
 	if (xaconn)
+	{
+		mylog("about to Disconnect\n");
+		SQLDisconnect(xaconn);
+		mylog("Freeing HANDLE_DBC\n");
 		SQLFreeHandle(SQL_HANDLE_DBC, xaconn);
+	}
 }
 
 HDBC	XAConnection::ActivateConnection(void)
@@ -134,28 +145,48 @@ HDBC	XAConnection::ActivateConnection(void)
 		}
 	}
 	MLOCK_RELEASE;
-	if (!xaconn)
-	{
-		ret = SQLSetEnvAttr(init_crit.env, SQL_ATTR_ODBC_VERSION, (PTR) SQL_OV_ODBC3, 0);
-		ret = SQLAllocHandle(SQL_HANDLE_DBC, init_crit.env, &xaconn);
-		if (SQL_SUCCEEDED(ret))
-		{
-			ret = SQLDriverConnect(xaconn, NULL,
-			 (SQLCHAR *) dsnstr.c_str(), SQL_NTS, NULL, SQL_NULL_DATA, NULL, SQL_DRIVER_COMPLETE);
-			if (!SQL_SUCCEEDED(ret))
-			{
-				SQLCHAR	sqlstate[8], errmsg[256];
+	if (xaconn)
+		return xaconn;
 
-				SQLGetDiagRec(SQL_HANDLE_DBC, xaconn,
-						1, sqlstate, NULL, errmsg,
-						sizeof(errmsg), NULL);
-				mylog("SQLDriverConnect return=%d sqlstate=%s error=%s\n", ret, sqlstate, errmsg);
-				SQLFreeHandle(SQL_HANDLE_DBC, xaconn);
-				xaconn = NULL;
-			}
-		}
+	ret = SQLSetEnvAttr(init_crit.env, SQL_ATTR_ODBC_VERSION, (PTR) SQL_OV_ODBC3, 0);
+	ret = SQLAllocHandle(SQL_HANDLE_DBC, init_crit.env, &xaconn);
+	if (!SQL_SUCCEEDED(ret))
+		return NULL;
+
+	ret = SQLDriverConnect(xaconn, NULL,
+		 (SQLCHAR *) dsnstr.c_str(), SQL_NTS, NULL, SQL_NULL_DATA, NULL, SQL_DRIVER_COMPLETE);
+	if (SQL_SUCCEEDED(ret))
+		return xaconn;
+	SQLCHAR	sqlstate[8], errmsg[256];
+
+	SQLGetDiagRec(SQL_HANDLE_DBC, xaconn,
+			1, sqlstate, NULL, errmsg,
+			sizeof(errmsg), NULL);
+	mylog("first SQLDriverConnect return=%d sqlstate=%s error=%s\n", ret, sqlstate, errmsg);
+	sqlState = (char *) sqlstate;
+	errMsg = (char *) errmsg;
+	if (!AuthenticationError())
+	{
+		SQLFreeHandle(SQL_HANDLE_DBC, xaconn);
+		return NULL;
 	}
-	return xaconn;
+	sqlState.empty();
+	errMsg.empty();
+	ret = SQLDriverConnect(xaconn, NULL,
+		 (SQLCHAR *) (dsnstr + ";Username=postgres;Password=postgres;sslmode=allow").c_str(), SQL_NTS, NULL, SQL_NULL_DATA, NULL, SQL_DRIVER_COMPLETE);
+	if (SQL_SUCCEEDED(ret))
+	{
+		mylog("second SQLDriverConnect success\n");
+		return xaconn;
+	}
+
+	SQLGetDiagRec(SQL_HANDLE_DBC, xaconn,
+			1, sqlstate, NULL, errmsg,
+			sizeof(errmsg), NULL);
+	mylog("second SQLDriverConnect return=%d sqlstate=%s error=%s\n", ret, sqlstate, errmsg);
+	sqlState = (char *) sqlstate;
+	errMsg = (char *) errmsg;
+	return NULL;
 }
 
 #define _BUILD_DLL_
@@ -286,7 +317,7 @@ static void XatabClear(void);
 static void finalize_globals(void)
 {
 	/* my(q)log is unavailable from here */
-	mylog("DETACHING PROCESS\n");
+	mylog("DETACHING From MSDTC PROCESS\n");
 	init_crit.finalize();
 }
 
@@ -530,15 +561,18 @@ EXTERN_C static int __cdecl xa_open(char *xa_info, int rmid, long flags)
 	int	xartn = XA_OK;
 	bool	bActivateConnection = bImmediateConnectDefault;
 
-	XAConnection	xconn(xa_info);
 	mylog("xa_open %s rmid=%d flags=%ld\n", xa_info, rmid, flags);
 	MLOCK_ACQUIRE;
-	init_crit.xatab.insert(pair<int, XAConnection>(rmid, xconn));
+	init_crit.xatab.insert(pair<int, XAConnection>(rmid, XAConnection(xa_info)));
 	MLOCK_RELEASE;
-	if (xconn.GetImmediateConnection())
+	map<int, XAConnection>::iterator p;
+	p = init_crit.xatab.find(rmid);
+	if (p == init_crit.xatab.end())
+		xartn = XAER_RMERR;
+	else if (p->second.GetImmediateConnection())
 	{
-		mylog("xa_open calls ActivateConnection %s\n", xconn.GetDsnstr().c_str());
-		if (xconn.ActivateConnection())
+		mylog("xa_open calls ActivateConnection %s\n", p->second.GetDsnstr().c_str());
+		if (p->second.ActivateConnection())
 			xartn = XA_OK;
 		else
 			xartn = XAER_RMERR;
@@ -550,7 +584,11 @@ EXTERN_C static int __cdecl xa_open(char *xa_info, int rmid, long flags)
 EXTERN_C static int __cdecl xa_close(char *xa_info, int rmid, long flags)
 {
 	mylog("xa_close rmid=%d flags=%ld\n", rmid, flags);
+	map<int, XAConnection>::iterator p;
 	MLOCK_ACQUIRE;
+	p = init_crit.xatab.find(rmid);
+	if (p != init_crit.xatab.end())
+		p->second.Reset();
 	init_crit.xatab.erase(rmid);
 	if (init_crit.xatab.size() == 0)
 		FreeEnv();
@@ -707,7 +745,12 @@ EXTERN_C static int __cdecl xa_recover(XID *xids, long count, int rmid, long fla
 		return rmcode;
 	HDBC	conn = p->second.ActivateConnection();
 	if (!conn)
+	{
+		if (p->second.AuthenticationError())
+			rmcode = 0;
+		mylog("%s returns %d\n", __FUNCTION__, rmcode);
 		return rmcode;
+	}
 	vector<string>	&vec = p->second.GetResultVec();
 	int	pos = p->second.GetPos();
 	if ((flags & TMSTARTRSCAN) != 0)
