@@ -904,7 +904,7 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 		ssize_t *next_cmd, SQLSMALLINT * pcpar,
 		po_ind_t *multi_st, po_ind_t *proc_return)
 {
-	const	char *sptr, *tstr, *tag = NULL;
+	const	char *tstr, *tag = NULL;
 	size_t	taglen = 0;
 	char	tchar, bchar, escape_in_literal = '\0';
 	char	in_literal = FALSE, in_ident_keyword = FALSE,
@@ -924,10 +924,9 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 		*next_cmd = -1;
 	tstr = query;
 	make_encoded_str(&encstr, conn, tstr);
-	for (sptr = tstr, bchar = '\0'; *sptr; sptr++)
+	for (bchar = '\0', tchar = encoded_nextchar(&encstr); tchar; tchar = encoded_nextchar(&encstr))
 	{
-		tchar = encoded_nextchar(&encstr);
-		if (ENCODE_STATUS(encstr) != 0) /* multibyte char */
+		if (MBCS_NON_ASCII(encstr)) /* multibyte char */
 		{
 			if ((UCHAR) tchar >= 0x80)
 				bchar = tchar;
@@ -945,7 +944,7 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 		}
 		if (!multi && del_found)
 		{
-			if (!isspace((UCHAR) tchar))
+			if (IS_NOT_SPACE(tchar))
 			{
 				multi = TRUE;
 				if (next_cmd)
@@ -955,7 +954,8 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 		if (in_ident_keyword)
 		{
 			if (isalnum(tchar) ||
-			    DOLLAR_QUOTE == tchar)
+			    DOLLAR_QUOTE == tchar ||
+			    '_' == tchar)
 			{
 				bchar = tchar;
 				continue;
@@ -967,12 +967,10 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 		{
 			if (tchar == DOLLAR_QUOTE)
 			{
-				if (strncmp(sptr, tag, taglen) == 0)
+				if (strncmp((const char *) ENCODE_PTR(encstr), tag, taglen) == 0)
 				{
 					in_dollar_quote = FALSE;
 					tag = NULL;
-					sptr += taglen;
-					sptr--;
 					encoded_position_shift(&encstr, taglen - 1);
 				}
 			}
@@ -998,16 +996,14 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 		}
 		else if (comment_level > 0)
 		{
-			if ('/' == tchar && '*' == sptr[1])
+			if ('/' == tchar && '*' == ENCODE_PTR(encstr)[1])
 			{
-				encoded_nextchar(&encstr);
-				sptr++;
+				tchar = encoded_nextchar(&encstr);
 				comment_level++;
 			}
-			else if ('*' == tchar && '/' == sptr[1])
+			else if ('*' == tchar && '/' == ENCODE_PTR(encstr)[1])
 			{
-				encoded_nextchar(&encstr);
-				sptr++;
+				tchar = encoded_nextchar(&encstr);
 				comment_level--;
 			}
 		}
@@ -1028,20 +1024,18 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 			{
 				del_found = TRUE;
 				if (next_cmd)
-					*next_cmd = sptr - query;
+					*next_cmd = encstr.pos;
 			}
 			else if (tchar == DOLLAR_QUOTE)
 			{
-				taglen = findTag(sptr, encstr.ccsc);
+				const char *ptr = (const char *) ENCODE_PTR(encstr);
+				taglen = findTag(ptr, encstr.ccsc);
 				if (taglen > 0)
 				{
 					in_dollar_quote = TRUE;
-					tag = sptr;
-					sptr += (taglen - 1);
+					tag = ptr;
 					encoded_position_shift(&encstr, taglen - 1);
 				}
-				else
-					num_p++;
 			}
 			else if (tchar == LITERAL_QUOTE)
 			{
@@ -1049,7 +1043,7 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 				escape_in_literal = CC_get_escape(conn);
 				if (!escape_in_literal)
 				{
-					if (LITERAL_EXT == sptr[-1])
+					if (LITERAL_EXT == ENCODE_PTR(encstr)[-1])
 						escape_in_literal = ESCAPE_IN_LITERAL;
 				}
 			}
@@ -1057,23 +1051,21 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 				in_dquote_identifier = TRUE;
 			else if ('-' == tchar)
 			{
-				if ('-' == sptr[1])
+				if ('-' == ENCODE_PTR(encstr)[1])
 				{
-					encoded_nextchar(&encstr);
-					sptr++;
+					tchar = encoded_nextchar(&encstr);
 					in_line_comment = TRUE;
 				}
 			}
 			else if ('/' == tchar)
 			{
-				if ('*' == sptr[1])
+				if ('*' == ENCODE_PTR(encstr)[1])
 				{
-					encoded_nextchar(&encstr);
-					sptr++;
+					tchar = encoded_nextchar(&encstr);
 					comment_level++;
 				}
 			}
-			if (!isspace((UCHAR) tchar))
+			if (IS_NOT_SPACE(tchar))
 				bchar = tchar;
 		}
 	}
@@ -1081,6 +1073,8 @@ SC_scanQueryAndCountParams(const char *query, const ConnectionClass *conn,
 		*pcpar = num_p;
 	if (multi_st)
 		*multi_st = multi;
+
+	MYLOG(0, "leaving...num_p=%d multi=%d\n", num_p, multi);
 }
 
 /*
@@ -1471,7 +1465,8 @@ SC_error_copy(StatementClass *self, const StatementClass *from, BOOL check)
 	BOOL	repstate;
 
 MYLOG(1, "entering %p->%p check=%i\n", from ,self, check);
-	if (self == from)	return;
+	if (!from)		return;	/* for safety */
+	if (self == from)	return; /* for safety */
 	if (check)
 	{
 		if (0 == from->__error_number)	/* SQL_SUCCESS */
@@ -1519,6 +1514,8 @@ SC_full_error_copy(StatementClass *self, const StatementClass *from, BOOL allres
 	PG_ErrorInfo		*pgerror;
 
 MYLOG(1, "entering %p->%p\n", from ,self);
+	if (!from)		return;	/* for safety */
+	if (self == from)	return; /* for safety */
 	if (self->__error_message)
 	{
 		free(self->__error_message);
@@ -2525,7 +2522,6 @@ libpq_bind_and_exec(StatementClass *stmt)
 		}
 
 		pstmt = stmt->processed_statements;
-		MYLOG(0, "execParams query=%s nParams=%d\n", pstmt->query, nParams);
 		QLOG(0, "PQexecParams: %p '%s' nParams=%d\n", conn->pqconn, pstmt->query, nParams);
 		log_params(nParams, paramTypes, (const UCHAR * const *) paramValues, paramLengths, paramFormats, resultFormat);
 		pgres = PQexecParams(conn->pqconn,
@@ -2551,7 +2547,6 @@ libpq_bind_and_exec(StatementClass *stmt)
 		plan_name = stmt->plan_name ? stmt->plan_name : NULL_STRING;
 
 		/* already prepared */
-		MYLOG(0, "execPrepared plan=%s nParams=%d\n", plan_name, nParams);
 		QLOG(0, "PQexecPrepared: %p plan=%s nParams=%d\n", conn->pqconn, plan_name, nParams);
 		log_params(nParams, paramTypes, (const UCHAR * const *) paramValues, paramLengths, paramFormats, resultFormat);
 		pgres = PQexecPrepared(conn->pqconn,
@@ -2586,7 +2581,6 @@ MYLOG(1, "get_Result=%p %p %d\n", res, SC_get_Result(stmt), stmt->curr_param_res
 			/* portal query command, no tuples returned */
 			/* read in the return message from the backend */
 			cmdtag = PQcmdStatus(pgres);
-			MYLOG(0, "command response: %s\n", cmdtag);
 			QLOG(0, "\tok: - 'C' - %s\n", cmdtag);
 			QR_set_command(res, cmdtag);
 			if (QR_command_successful(res))
@@ -2627,8 +2621,7 @@ MYLOG(1, "get_Result=%p %p %d\n", res, SC_get_Result(stmt), stmt->curr_param_res
 			CC_set_error(conn, CONNECTION_BACKEND_CRAZY, "Unexpected protocol character from backend (send_query)", func);
 			CC_on_abort(conn, CONN_DEAD);
 
-			MYLOG(0, "PQexecxxxxxx: error - %s\n", CC_get_errormsg(conn));
-			QLOG(0, "error: - (%d) - %s\n", pgresstatus, CC_get_errormsg(conn));
+			QLOG(0, "PQexecXxxx error: - (%d) - %s\n", pgresstatus, CC_get_errormsg(conn));
 			break;
 	}
 
@@ -2768,7 +2761,6 @@ MYLOG(0, "sta_pidx=%d end_pidx=%d num_p=%d\n", sta_pidx, end_pidx, num_params);
 	}
 	cstatus = PQcmdStatus(pgres);
 	QLOG(0, "\tok: - 'C' - %s\n", cstatus);
-	MYLOG(0, "\tok: - 'C' - %s\n", cstatus);
 	if (stmt->plan_name)
 		SC_set_prepared(stmt, PREPARED_PERMANENTLY);
 	else
@@ -2838,7 +2830,6 @@ ParseAndDescribeWithLibpq(StatementClass *stmt, const char *plan_name,
 		goto cleanup;
 
 	/* Describe */
-	MYLOG(0, "describing plan_name=%s\n", plan_name);
 	QLOG(0, "\tPQdescribePrepared: %p plan_name=%s\n", conn->pqconn, plan_name);
 
 	pgres = PQdescribePrepared(conn->pqconn, plan_name);
@@ -2866,7 +2857,7 @@ ParseAndDescribeWithLibpq(StatementClass *stmt, const char *plan_name,
 	/* Extract parameter information from the result set */
 	num_p = PQnparams(pgres);
 MYLOG(1, "num_params=%d info=%d\n", stmt->num_params, num_p);
-	if (get_qlog() > 0)
+	if (get_qlog() > 0 || get_mylog() > 0)
 	{
 		int	i;
 
